"""
coding: utf-8
Programmation en langage Python
Lycée Raoul Follereau

Tracé de la caractéristique d'un conducteur ohmique
Classe de seconde
Chapitre 2 - Signaux et capteurs électriques

Importation de différentes bibliothèques
    Numpy pour les calculs numériques, alias np (pour faciliter le codage du programme)
    Matplotlib pour les graphiques, alias plt
    scipy.stats pour la modélisation

"""

import numpy as np
import matplotlib.pyplot as plt
import scipy.stats as sc

# Valeurs de la tension U entre les bornes du conducteur ohmique en fonction de l'intensité I du courant qui le traverse
# on définit un tableau du type array (ce qui permet de faire des opérations sur les tableaux)
I=np.array([0,15,40,86,108,136])
U=np.array([0,0.35,0.9,1.70,2.12,2.72])

# on efface toutes les figures précédentes
plt.clf()

plt.plot(I, U, label='U=f(I)', color = '#FF0000', marker= '*', linestyle = ':', linewidth=2.0)

plt.title('caractéristique conducteur ohmique', fontsize=18)

plt.xlabel('Axe des abscisses I en mA', fontsize=14)
plt.ylabel('Axe des ordonnées U en V', fontsize=14)

plt.grid(True)

plt.xlim(-10, 150)
plt.ylim(-0.5,3)

# Modélisation du graphique qui est une fonction affine

droite=sc.linregress(I, U) # calcul du coefficient directeur et de l'ordonnée à l'origine

coefficient=droite.slope   # on récupère la valeur du coefficient directeur
print("Le coefficient directeur de la droite est : ", coefficient)

ordonnee_origine=droite.intercept # on récupère la valeur de l'ordonnée à l'origine
print("L'ordonnée à l'origine est : ", ordonnee_origine)

# Tracé de la droite de régression linéaire
Umod=coefficient*I+ordonnee_origine # on calcule les valeurs de Umod en fonction des valeurs de I
plt.plot(I, Umod, label='Umod=f(I)', color='blue', marker= 'o', linestyle = '-', linewidth=1.0)



plt.legend()

plt.savefig('caracteristique_resistance_nom_prenom.png')

plt.show()



